#!/usr/bin/env python3

import sys
import re
import fileinput


def usage():
    print("Usage: [-iI ignore case (default: false)] [-lL print words instead count (default: false)]")


def exit_abnormal():
    print("Invalid argument input")
    usage()
    sys.exit(1)


def split_file(inputfile, ignore_t):
    pat = "[\^\`\'\"\s'%^~!@#§()$%^&*_+-={[\]}}|,:;<>.?]+"
    words = []
    try:
        for line in fileinput.input(inputfile):
            zwisch = re.split(pat, line)
            if (zwisch[-1] == ''):
                zwisch.remove('')
            words = words + zwisch
            # if (zwisch == "None"):
            #    zwisch.remove("None")
        if ignore_t:
            return list(filter(None, [w.lower() for w in words])) #filter empty none values#
        else:
            return list(filter(None, words)) #filter empty none values#


    except FileNotFoundError:
        print("File not found " + str(inputfile))
        exit_abnormal()


def count_words(to_count, dict_words):
    for k, v in dict_words.items(): #key and value of dictionary
        for c in to_count:  # list of splitted words
            if c == k:
                v = v + 1

        dict_words[k] = v
            # and implement delete

    dict_words = dict(sorted(dict_words.items(), key=lambda x: x[0]))
    return sorted(dict_words.items(), key=lambda x: x[1], reverse=True)


# if a word is separated to due a new line it is counted as two words.
# third argument must be the file
def main(argv):
    inputfile = argv[-1]
    argv = [a.lower() for a in argv]  # excepts iI and lL cases
    if not argv:
        exit_abnormal()
    ignore_t = False
    word = False
    arg = list(set(argv))  # removes duplicates
    for opt in argv:
        if opt == '-h':
            arg.remove("-h")
            usage()
            sys.exit()

        if opt in "-i":
            arg.remove("-i")
            ignore_t = True

        if opt in "-l":
            arg.remove("-l")
            word = True


    words = split_file(inputfile, ignore_t)

    #if list is set true print words if not print counts
    dict_words = dict((zd, 0) for zd in list(set(words)))
    if word:
        [print(k, v) for k, v in count_words(words, dict_words)]
    else:
        print("{0} / {1}".format(len(dict_words), len(words)))

if __name__ == "__main__":
    main(sys.argv[1:4])



#!/usr/bin/env python3
import sys
import fileinput
import argparse
import numpy as np
import copy

def usage():
    print("Usage of K-letSchuffle: [-N number of sequences to create][-K assure frequency of sub-sequences of length k]")

def exit_abnormal():
    print("Invalid argument input")
    usage()
    sys.exit(1)

class kletschuffle:
    def __init__(self, inputfile=[], n_sequence=0, k=2):
        self.k=k-1
        self.inputfile = inputfile
        self.n_sequence = n_sequence
        self.in_sequence=""
        self.shuffle_sequence=[]
        #sym,   id, neighbors, seen, next
        # key,   0, 1        , 2   , 3
        self.kmers=[]
        self.root=""
        self.start=""
        self.multigraph=[]#vermulitch unnötig
        self.valid=False

    def print(self):
        u=self.start
        self.shuffle_sequence.append(u)
        while self.multigraph[u][1]:
            v=self.multigraph[u][1][0]
            self.multigraph[u][1].pop(0)
            u=v
            self.shuffle_sequence.append(u)
            #print(self.multigraph)
            #print(self.shuffle_sequence)
        if len("".join(self.shuffle_sequence[::self.k])) != len(self.in_sequence):
            self.shuffle_sequence="".join(self.shuffle_sequence[::self.k]) + self.shuffle_sequence[-1][-1]
        else:
            self.shuffle_sequence="".join(self.shuffle_sequence[::self.k])
        if len(self.shuffle_sequence) == len(self.in_sequence):
            self.valid=True
            print(self.shuffle_sequence)

    def print_result(self):
        u=self.start
        self.shuffle_sequence.append(u)
        while self.multigraph[u][1]:
            v=self.multigraph[u][1][0]
            self.multigraph[u][1].pop(0)
            u=v
            self.shuffle_sequence.append(u)
            #print(self.multigraph)
            #print(self.shuffle_sequence)
        if len("".join(self.shuffle_sequence[::self.k])) != len(self.in_sequence):
            self.shuffle_sequence="".join(self.shuffle_sequence[::self.k]) + self.shuffle_sequence[-1][-1]
        else:
            self.shuffle_sequence="".join(self.shuffle_sequence[::self.k])
        print(self.multigraph)
        print(self.shuffle_sequence)
        print(len(self.shuffle_sequence))

    def read_data(self):
        # input data specifications:
        # input sequence must be in one line
        try:
            for line in fileinput.input(self.inputfile):
                self.in_sequence=str(line).rstrip()
                break
        except FileNotFoundError:
            print("File not found " + str(self.inputfile))
            exit_abnormal()

    def create_kmer_one(self):
        self.start=self.in_sequence[0:self.k]
        for i in range(0, (len(self.in_sequence)-self.k+1)):
            self.kmers.append(self.in_sequence[i:(i + self.k)])
        self.kmers=dict(zip(self.kmers, range(0, len(self.kmers)) ))
        self.kmers={k: [[k], []] for i, k in enumerate(self.kmers)}
        self.root=self.in_sequence[i:(i + self.k)]

    def create_multigraph(self):
        for i in range(0, (len(self.in_sequence)-self.k)):
            self.kmers[self.in_sequence[i:(i+self.k)]][1].append(self.kmers[self.in_sequence[(i+1):(i+1 + self.k)]][0][0])

    #RandomTreeWithRoot(r)
    #Wilson's algorithm from https://bmcbioinformatics.biomedcentral.com/track/pdf/10.1186/1471-2105-9-192.pdf
    #The root is the last k-let of the sequence
    #starting vertex is the first k-let of the sequence (Wilson’s algorithm).
    def randomtreewithroot(self):
        self.multigraph=copy.deepcopy(self.kmers)
        [v.append([False]) for k, v in self.multigraph.items()]
        self.multigraph[self.root][2]=[True] #set

        #starting node
        counter=0
        break_bug=1000
        for idx in self.multigraph.values():
            u=idx[0][0]
            while not self.multigraph[u][2][0]:#while not "seen"
                r=np.random.choice(self.multigraph[u][1], replace=True)
                self.multigraph[u].append([r])#choose random neighbour as next
                u=r
                #u=self.multigraph[u][3][0]
            u=idx[0][0]
            while not self.multigraph[u][2][0]: #while not "seen"
                self.multigraph[u][2][0]=True #set seen to true
                u=self.multigraph[u][3][0] #go to "next"
        self.multigraph[self.root].append("root")
        #print(self.multigraph)

    def shuffle(self):
        for idx in self.multigraph:
            if self.multigraph[idx][1]:
                if len(self.multigraph[idx][1])<=1:#if there is just one neighbour no shuffle needed
                    continue
                else:
                    if not self.multigraph[idx][3] == "root":
                        zwisch=self.multigraph[idx][1]
                        zwisch.remove(self.multigraph[idx][3][0])
                        self.multigraph[idx][1]=list(np.random.choice(zwisch, size=len(zwisch), replace=False)) + [self.multigraph[idx][3][0]]
                    else:
                        pass
                        #self.multigraph[idx][1]=list(np.random.choice(zwisch, size=len(zwisch), replace=False))
        #print(self.multigraph)

    def kletshuffle(self):
        self.read_data()
        self.create_kmer_one()
        self.create_multigraph()
        counter=0
        #for i in range(0, self.n_sequence):
        while counter < self.n_sequence:
            self.shuffle_sequence=[]
            self.randomtreewithroot()
            self.shuffle()
            self.print()
            if self.valid:
                self.valid=False
                counter = counter + 1


def main(argv):
    KlettS = kletschuffle(inputfile=argv.inputfile, n_sequence=argv.N, k=argv.K)
    KlettS.kletshuffle()

    sys.exit()

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Usage: [-N number of sequences to generate]")
    parser.add_argument("inputfile")
    parser.add_argument("-N", required=True, type=int, help="Number of sequences")
    parser.add_argument("-K", required=True, type=int, help="K-let")
    argv=parser.parse_args()
    main(argv)
    sys.exit()



#!/usr/bin/env python3

#Traveling salesman problem (TSP)
#Approximately solved by branch and bound optimazation algorithm.

import linecache
import sys
import numpy as np
import pandas as pd
from math import inf


def usage():
    print("Usage: [input file missing]")


def exit_abnormal():
    print("Invalid argument input")
    usage()
    sys.exit(1)



class BBTreeNode:

    def __init__(self, cost=0, constraint=0, feasible=[], solution=[], CM=[], final_solution =[]):
        #self.ownnode=feasible[0]
        self.cost = cost  # contains the cost
        self.constraint = constraint
        self.feasible = feasible  # what nodes can be expanded
        self.solution = solution  # contains the current solution (BE, IG...)
        self.CM=CM
        self.final_solution=final_solution


    def check_cost(self):
        #returns true and continues if cost < constraints
        if self.cost > self.constraint:
            return False
        return True

    def update_cost(self):
        if isinstance(self.solution, list):
            node=self.solution[-1]
        if isinstance(self.solution, str):
            node=self.solution
        self.cost=self.cost+self.CM[node[0]][node[1]]


    def update_feasible(self):
        feasible = self.feasible.copy()
        if isinstance(self.solution, list):
            node=self.solution[-1]
        if isinstance(self.solution, str):
            node=self.solution
        # feasible is a list of possible nodes - delets the current "added" node from the lsit
        for ci in range(0, len(node)):
            c = node[ci]
            to_pop = []
            for i in feasible:
                # returns position of the match if its not present returns -1
                if i.find(c) >= 0:
                    to_pop.append(i)
            if isinstance(feasible, list):
                [feasible.remove(s) for s in to_pop]

            if isinstance(feasible, str):
                feasible=[]

        return feasible

    def update_finalsolution(self):
        global result
        if not result:
            result = [self.solution + [self.cost]]
        else:
            bool_res = []
            for a in result:
                bool_res.append(set(a) == set(self.solution + [self.cost]))
            if sum(bool_res) == 0:
                result.append(self.solution + [self.cost])

    def bab(self):
        self.update_cost()
        if self.check_cost()==True:
            feasible = self.update_feasible()
            if isinstance(feasible, list):  # len(self.feasible) > 0:
                # meaning if there ary any possible solutiosn left
                if isinstance(self.solution, str):
                    for f in feasible:
                        zwisch = [self.solution] + [f]
                        BB = BBTreeNode(cost=self.cost, constraint=self.constraint, feasible=feasible, solution=zwisch, CM=self.CM)
                        BB.bab()
                if isinstance(self.solution, list):
                    # meaning if there ary any possible solutiosn left
                    for f in feasible:
                        zwisch = self.solution + [f]
                        BB = BBTreeNode(cost=self.cost, constraint=self.constraint, feasible=feasible, solution=zwisch, CM=self.CM)
                        BB.bab()


            # last case if feasible is string is missing
            if not feasible:
                self.update_finalsolution()
                #result = self.solution



def main(argv):
    if not argv:
        usage()
        sys.exit(1)

    inputfile = argv[-1]
    argv = [a.lower() for a in argv]  # excepts iI and lL cases
    opti = False
    if not argv:
        exit_abnormal()
    ignore_t = False
    word = False
    arg = list(set(argv))  # removes duplicates
    for opt in argv:
        if opt in "-o":
            arg.remove("-o")
            opti = True

    #Data preparation start
    try:
        nc, upbound = map(int, linecache.getline(inputfile, 1).split())  # check for integers nc=number of cities and upbound maximum cost
    except Exception as e:
        print(e)

    try:
        # get citiie names
        cities = linecache.getline(inputfile, 2).split()
        #read cost data
        dtype = [(c, np.int_) for c in cities]
    except Exception as e:
        print(e)

    try:
        df=np.genfromtxt(inputfile, skip_header=1, dtype=dtype, names=True )#, names =["a", "b", "c", "d", "e", "f", "g", "h"])#cost matrix
        CM=pd.DataFrame(df, index=cities)
        CM[CM>upbound] = inf #Sets all values exceedign the upper boundary upbound to infinity
        CM[CM == -1] = inf #diagonal elements to inf
        CM[CM == 0] = inf #sets values which can no be reached to inf

    except Exception as e:
        print(e)
    #Data preparation end

    #creating feasible solutions BE and EB are the same
    start_feasible=[]
    for i in range(len(CM.columns)):
        for j in range(i + 1, len(CM.columns)):
            start_feasible.append(CM.columns[i] + CM.columns[j])

    initial_nodes=[]
    for i in range(1, len(CM.columns)):
        #creates initial nodes
        initial_nodes.append(CM.columns[0] + CM.columns[i])

    global result
    result = []
    for init in range(0, len(initial_nodes)):
        # start with first node
        node = initial_nodes[init]
        # access costs
        cost = CM[str(node[0])][str(node[1])]
        #def __init__(self, cost=0, constraint=0, feasible=[], solution=[]):
        BB=BBTreeNode(cost=0, constraint=upbound, feasible=start_feasible, solution=node, CM=CM)
        BB.bab()


    if opti:
        print(min([r[-1] for r in result]))
    else:
        for r in result:
            print(' '.join(r[0:-1]))


if __name__ == "__main__":
    main(sys.argv[1:3])
    sys.exit()


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu May  18 2021
@author: philippf
"""

import sys
import argparse
from eerah_A5.programs import RollingDice, WordCount, Administration, Manhattan, MonoShuffle, KLetShuffle

def main():
    parser = argparse.ArgumentParser(description="eerah_A5 APBC2021 - Assignment A1, A2, A3, A4.")
    parser.add_argument("inputfile", help="inputfile")
    parser.add_argument("-A1", action='store_true', help="Word Count of a given file")
    parser.add_argument("-i", action='store_true')
    parser.add_argument("-l", action='store_true')

    parser.add_argument("-A2", action="store_true", help="Optimizing the administration of Atirasu")
    parser.add_argument("-o", action="store_true",
                        help="if given: the program optimizes the cost (instead of enumerating)")

    parser.add_argument("-A3", action="store_true", help="The Manhattan Tourist Problem")
    parser.add_argument("-d", action="store_true", default=False, help="accepts also diagnoals (default: false)")
    parser.add_argument("-t", action="store_true", default=False, help="prints out best path (default: false)")

    parser.add_argument("-A4", choices=["RollingDice", "MonoShuffle", "KletShuffle"],
                        help="Shuffle a given sequenve based on choices")

    parser.add_argument("-N", type=int, default=1, help="Number of random sequences")
    parser.add_argument("-K", type=int, default=2, help="size of klet klet (2) ")

    argv = parser.parse_args()
    if argv.A1:
        WordCount.main(sys.argv[1:5])
    elif argv.A2:
        Administration.main(sys.argv[1:4])
    elif argv.A3:
        Manhattan.main(sys.argv[1:5])
    elif argv.A4:
        if argv.A4 == "RollingDice":
            RollingDice.main(argv)
        if argv.A4 == "MonoShuffle":
            MonoShuffle.main(argv)
        if argv.A4 == "KletShuffle":
            KLetShuffle.main(argv)


if __name__ == '__main__':
    main()
    sys.exit(0)



#!/usr/bin/env python3
import sys
import fileinput
import argparse
import numpy as np
import copy

def usage():
    print("Usage: [-N number of sequences to generate] [input sequnece from file - sequnce must be in one line]")

def exit_abnormal():
    print("Invalid argument input")
    usage()
    sys.exit(1)

class monosh:
    def __init__(self, inputfile=[], n_sequence=0):
        self.inputfile = inputfile
        self.n_sequence = n_sequence
        self.in_sequence=[]
        self.shuffle_sequence=[]
        self.base_frequency={}

    def print(self):
        print("".join(e for e in self.shuffle_sequence))

    def read_data(self):
        # input data specifications:
        # input sequence must be in one line
        try:
            for line in fileinput.input(self.inputfile):
                self.in_sequence=list(str(line).rstrip())
                break
        except FileNotFoundError:
            print("File not found " + str(self.inputfile))
            exit_abnormal()

    def swap(self, i, j):#i equals current position and j is the position to change with
        zwisch=self.shuffle_sequence[i]
        self.shuffle_sequence[i]=self.shuffle_sequence[j]
        self.shuffle_sequence[j]=zwisch
        del zwisch

    def shuffle(self):
        for i in range(0, self.n_sequence):
            la = list(np.arange(0, len(self.in_sequence)))  # list from 0 to length of sequence
            self.shuffle_sequence=copy.deepcopy(self.in_sequence)
            for v, k in enumerate(self.shuffle_sequence):
                self.swap(i=v, j=np.random.choice(la))
                la.pop(0)
            self.print()

def main(argv):
    RD = monosh(inputfile=argv.inputfile, n_sequence=argv.N)
    RD.read_data()
    RD.shuffle()
    sys.exit()

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Usage: [-N number of sequences to generate]")
    parser.add_argument("inputfile")
    parser.add_argument("-N", required=True, type=int, help="Number of sequences")
    argv=parser.parse_args()
    main(argv)
    sys.exit()



#!/usr/bin/env python3
import sys
import fileinput
import argparse
import numpy

def usage():
    print("Usage: [-N number of sequences to generate] [input sequnece from file - sequnce must be in one line]")

def exit_abnormal():
    print("Invalid argument input")
    usage()
    sys.exit(1)

class dice:
    def __init__(self, inputfile=[], n_sequence=0):
        self.inputfile = inputfile
        self.n_sequence = n_sequence
        self.in_sequence=""
        self.base_frequency={}

    def print(self):
        print(self.in_sequence)

    def read_data(self):
        # input data specifications:
        # input sequence must be in one line
        try:
            for line in fileinput.input(self.inputfile):
              self.in_sequence=str(line).rstrip()
              break
        except FileNotFoundError:
            print("File not found " + str(self.inputfile))
            exit_abnormal()

    def get_frequency(self):
        present_bases = {base: 0 for base in
                         set(self.in_sequence)}  # unique bases in sequence e.g. {'A': 0, 'S': 0, 'D': 0, 'F': 0}
        for base in self.in_sequence:
            present_bases[base] = present_bases[base] + 1

        for base in present_bases:
            present_bases[base] = round(present_bases[base] / len(self.in_sequence), ndigits=8)
        self.base_frequency = present_bases

    def shuffle(self):
      for i in range(0, self.n_sequence):
          r=numpy.random.choice([base for base in self.base_frequency.keys()], p=[freq for freq in self.base_frequency.values()], size=len(self.in_sequence))
          print("".join(e for e in r))

def main(argv):
    RD = dice(inputfile=argv.inputfile, n_sequence=argv.N)
    RD.read_data()
    RD.get_frequency()
    RD.shuffle()
    sys.exit()

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Usage: [-N number of sequences to generate]")
    parser.add_argument("inputfile")
    parser.add_argument("-N", required=True, type=int, help="Number of sequences")
    argv=parser.parse_args()
    main(argv)
    sys.exit()



#!/usr/bin/env python3
import sys
import fileinput


def usage():
    print("Usage: [-t prints out best path (default: false)] [-d accepts also diagnoals (default: false)]")


def exit_abnormal():
    print("Invalid argument input")
    usage()
    sys.exit(1)


class manhattan:
    def __init__(self, inputfile=[], diagonal=False, south_matrix=[], east_matrix=[], diag_matrix=[], path=[], trace=False):
        self.south_matrix = south_matrix  # contains the nort-south data
        self.east_matrix = east_matrix  # contains  the west-east data
        self.diag_matrix = diag_matrix  # contains  the diagonal data
        self.inputfile = inputfile
        self.diagonal = diagonal
        self.trace=trace
        self.res_dict = {(0, 0): [0, ""]}
        self.path=[]

    def print(self):
        print(self.res_dict)
        #print(self.diagonal)

    def print_result(self):
        print(round(self.res_dict[(len(self.south_matrix), len(self.east_matrix[0]))][0], ndigits=5))
        #path is stored reverse
        if self.path and self.trace:
            print("".join(self.path[::-1]))

    def read_data(self):

        # input data specifications:
        # comments must start with # at the beginning of the line.
        # manhattan must be quadratic
        # empty rows are accepted and ignored
        # First datapart must be north-south
        # second datapart must be west-east
        # third can be diagnoals

        try:
            counter = 0
            counter_diagonal = 0
            n = 0
            for line in fileinput.input(self.inputfile):
                if not (line.startswith("#") or len(line.split()) == 0):
                    current_split = line.split()
                    curren_line_length = len(current_split)
                    if counter == 0:  # if counter == 0 then the first line of the north-south part will be read
                        m = curren_line_length
                        counter = 1
                    if m == curren_line_length:
                        self.south_matrix.append([float(i) for i in current_split])
                        n = n + 1
                    if m != curren_line_length and counter == 1:
                        counter = 2

                    if counter == 2 and counter_diagonal <= m:
                        self.east_matrix.append([float(i) for i in current_split])
                        counter_diagonal = counter_diagonal + 1
                    if m < counter_diagonal and counter == 2 and self.diagonal:
                        counter = 3
                        #continue
                    if n < counter_diagonal and counter == 3:
                        self.diag_matrix.append([float(i) for i in current_split])
        except FileNotFoundError:
            print("File not found " + str(self.inputfile))
            exit_abnormal()

    def manhattanTourist(self):
        # n, m, sout and east
        n = len(self.south_matrix)
        m = len(self.east_matrix[0])
        for i in range(0, n):
            self.res_dict[(i + 1, 0)] = [self.res_dict[(i, 0)][0] + self.south_matrix[i][0], "S"]
        for i in range(0, m):
            self.res_dict[(0, i + 1)] = [self.res_dict[(0, i)][0] + self.east_matrix[0][i], "E"]

        if self.diagonal:
            for i in range(1, n + 1):
                for j in range(1, m + 1):
                    south=self.res_dict[(i - 1, j)][0] + self.south_matrix[i - 1][j]
                    east=self.res_dict[(i, j - 1)][0] + self.east_matrix[i][j - 1]
                    diag=self.res_dict[(i - 1, j - 1)][0] + self.diag_matrix[i - 1][j - 1]
                    if south >= east and south >= diag:
                        self.res_dict[(i, j)]=[south, "S"]
                    elif east >= diag:
                        self.res_dict[(i, j)]=[east, "E"]
                    else:
                        self.res_dict[(i, j)]=[diag, "D"]
        else:
            for i in range(1, n + 1):
                for j in range(1, m + 1):
                    south=self.res_dict[(i - 1, j)][0] + self.south_matrix[i - 1][j]
                    east=self.res_dict[(i, j - 1)][0] + self.east_matrix[i][j - 1]
                    if south >= east:
                        self.res_dict[(i, j)]=[south, "S"]
                    else:
                        self.res_dict[(i, j)]=[east, "E"]


    def backtracking(self):
        i=len(self.south_matrix)
        j=len(self.east_matrix[0])
        w=self.res_dict[(i, j)][1]
        while w:
            w=self.res_dict[(i, j)][1]
            if not w:
                break
            else:
                if w in "E":
                    j=j-1
                    self.path.append("E")
                if w in "S":
                    i=i-1
                    self.path.append("S")
                if w in "D":
                    i=i-1
                    j=j-1
                    self.path.append("D")



# if a word is separated to due a new line it is counted as two words.
# third argument must be the file
def main(argv):
    inputfile = argv[-1]
    argv = [a.lower() for a in argv]  # excepts iI and lL cases
    if not argv:
        exit_abnormal()
    trace = False
    diagonal = False
    arg = list(set(argv))  # removes duplicates
    for opt in argv:
        if opt == '-h':
            arg.remove("-h")
            usage()
            sys.exit()

        if opt in "-t":
            arg.remove("-t")
            trace = True

        if opt in "-d":
            arg.remove("-d")
            diagonal = True

    MH = manhattan(inputfile, diagonal=diagonal, trace=trace)
    MH.read_data()
    MH.manhattanTourist()
    MH.backtracking()
    MH.print_result()

    sys.exit()


if __name__ == "__main__":
    main(sys.argv[1:4])
    sys.exit()



#!/usr/bin/env python3
from __future__ import absolute_import
from setuptools import setup, find_packages


with open("README.md", "r") as fh_readme:
    LONG_DESCRIPTION = fh_readme.read()

setup(
    name="eerah-A5",
    version = "0.0.1",
    description = "Contains programs for the course Algorithmen und Programmentwicklung für die Biologische Chemie",
    author="Philipp Fischer",
    author_email="fischer-philipp@gmx.net",
    long_description=LONG_DESCRIPTION,
    long_description_content_type = "text/markdown",
    install_requires=["numpy", "pandas"],
    packages=find_packages(),
    entry_points={"console_scripts": ["eerah-A5=eerah_A5.__main__:main", ], },
    include_package_data=True,
    keywords=["APBC2021", "python3"],
    python_requires=">=3.6",
    classifiers= [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)

